@@ -33,13 +33,13 @@ GLib = get_introspection_module('GLib')
 
 __all__ = []
 
-from gi._glib import option
+from gi import _option as option
 option  # pyflakes
 __all__.append('option')
 
 
 # Types and functions still needed from static bindings
-from gi._glib import _glib
+from gi._gi import _glib
 GError = _glib.GError
 OptionContext = _glib.OptionContext
 OptionGroup = _glib.OptionGroup
